summaryrefslogtreecommitdiffstats
path: root/base/common/src/com/netscape/certsrv/key/KeyData.java
diff options
context:
space:
mode:
Diffstat (limited to 'base/common/src/com/netscape/certsrv/key/KeyData.java')
-rw-r--r--base/common/src/com/netscape/certsrv/key/KeyData.java14
1 files changed, 7 insertions, 7 deletions
diff --git a/base/common/src/com/netscape/certsrv/key/KeyData.java b/base/common/src/com/netscape/certsrv/key/KeyData.java
index 82e23ed9e..4fcb6b420 100644
--- a/base/common/src/com/netscape/certsrv/key/KeyData.java
+++ b/base/common/src/com/netscape/certsrv/key/KeyData.java
@@ -46,7 +46,7 @@ public class KeyData {
String algorithm;
@XmlElement
- Integer strength;
+ Integer size;
public KeyData() {
// required for JAXB (defaults)
@@ -111,16 +111,16 @@ public class KeyData {
}
/**
- * @return the strength
+ * @return the size
*/
- public Integer getStrength() {
- return strength;
+ public Integer getSize() {
+ return size;
}
/**
* @param strength the strength to set
*/
- public void setStrength(Integer strength) {
- this.strength = strength;
+ public void setSize(Integer size) {
+ this.size = size;
}
}
@@ -111,16 +111,16 @@ public class KeyData {
}
/**
- * @param strength the strength to set
+ * @param size the size to set
*/